pub struct Rt { /* private fields */ }Implementations
Sourceimpl Rt
impl Rt
pub fn create(config: Mm1NodeConfig) -> Result<Self, RtCreateError>
pub fn with_actor_failure_sink( self, tx_actor_failure: UnboundedSender<(Address, AnyError)>, ) -> Self
pub fn with_tap(self, key: impl Into<String>, tap: Arc<dyn MessageTap>) -> Self
Sourcepub fn run(
&self,
main_actor: BoxedRunnable<ActorContext>,
) -> Result<(), RtRunError>
pub fn run( &self, main_actor: BoxedRunnable<ActorContext>, ) -> Result<(), RtRunError>
Runs the main actor, then makes a bounded, best-effort attempt to stop actors started during this run.
Tokio task cancellation is cooperative. Actor code that blocks a runtime thread or does not yield may keep running and retain resources after this method returns.